<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="100px">
      <el-form-item label="收费员" prop="tollCollectorId">
        <el-select v-model="queryParams.tollCollectorId" filterable style="width: 200px" placeholder="请选择交款员" clearable
          @clear="getCompanyList">
          <el-option v-for="dict in CompanyList" :key="dict.userId" :label="dict.nickName" :value="dict.userId" />
        </el-select>
      </el-form-item>
      <el-form-item label="起始时间" prop="accountBeginTime">
        <el-date-picker v-model="queryParams.accountBeginTime" type="datetime" placeholder="选择起始时间">
        </el-date-picker>
      </el-form-item>
      <el-form-item label="截止时间" prop="accountEndTime">
        <el-date-picker v-model="queryParams.accountEndTime" type="datetime" placeholder="选择截止时间">
        </el-date-picker>
      </el-form-item>

      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['hosp:water:edit']">汇总</el-button>
      </el-col>
    </el-row>
    <el-table style="width: 80%" :data="list"  border max-height="720px" @selection-change="handleSelect">
      <el-table-column type="selection" width="55"> </el-table-column>
      <el-table-column label="交款员" align="center" prop="tollCollector" :show-overflow-tooltip="true" />
      <el-table-column label="收费金额" align="center" prop="amountReceived" :show-overflow-tooltip="true" />
      <el-table-column label="退费金额" align="center" prop="refundAmount" :show-overflow-tooltip="true" />
      <el-table-column label="应交款" align="center" prop="payable" :show-overflow-tooltip="true" />
      <el-table-column label="交账时间" align="center" prop="createTime" :show-overflow-tooltip="true" />
      <el-table-column label="起止日期" align="center" prop="accountBeginTime" :show-overflow-tooltip="true" />
      <el-table-column label="终止日期" align="center" prop="accountEndTime" :show-overflow-tooltip="true" />
    </el-table>
    <!-- <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    /> -->
  </div>
</template>

<script>
import { getlistWater, getWater, getdatalist, addTjSummary } from "@/api/hosp/water";
import { getHzList, } from "@/api/hosp/Summary";
import moment from "moment";
export default {
  name: "Water",
  data() {
    return {
      value1: "",
      begTime: "",
      endTime: "",
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      CompanyList: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 体检流水表格数据
      list: [],
      tollCollectorDetails: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        tollCollectorId: null,
        accountBeginTime: null,
        accountEndTime: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        createTime: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        updateTime: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        deleted: [
          { required: true, message: "删除标记不能为空", trigger: "blur" }
        ]
      }
    };
  },
  created() {
    this.getCompanyList()
    this.getList();
  },
  methods: {
    // 下拉框显示
    getCompanyList() {
      this.loading = true;
      getdatalist().then((response) => {
        this.CompanyList = response.data;
        this.loading = false;
      });
    },
    /** 查询体检流水列表 */
    getList() {
      this.loading = true;
      if (this.queryParams.accountBeginTime != null) {
        this.queryParams.accountBeginTime = moment(this.queryParams.accountBeginTime).format("YYYY-MM-DD HH:mm:ss")
        this.queryParams.accountEndTime = moment(this.queryParams.accountEndTime).format("YYYY-MM-DD HH:mm:ss")
      }

      getlistWater(this.queryParams).then(response => {
        this.list = response.data;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        proId: null,
        pacId: null,
        copeWith: null,
        paidIn: null,
        discount: null,
        payStasus: null,
        payType: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        deleted: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },

    handleSelect(selection, val) {
      if (selection.length > 1) {
        this.single = false
      } else {
        this.single = true
      }
      selection.forEach(element => {
        this.ids.push(element.id)
      });

    },

    /** 修改按钮操作 */
    handleUpdate() {
      addTjSummary(this.ids).then(response => {
        let accountId = response.msg
        const viewNum = "872704875763019776";
        const params = { viewNum, accountId };
        this.$tab.openPage("汇总结账单", "/report/settlement", params);
      });
    },
  }
};
</script>